*****************************************************************.
* Programme destin au calcul des quintiles et dciles de       *.
* population selon la dpense per capita.                       *.
* Le programme produit aussi certains tableaux de contrle.     *.
*****************************************************************.

GET
  FILE='C:\_Maroc\Data\Spss\Annuel\Dep_cat.sav'.
EXECUTE.

* Calcul des quintiles et dciles de population selon la dpense *.
* totale per capita, selon urbain/rural et au niveau national.   *.
* ---------------------------------------------------------------*.
WEIGHT
  BY coef_pop .
RANK
  VARIABLES=dep_pc  (A) BY milieu  /NTILES (5) /PRINT=NO
  /TIES=MEAN .
RANK
  VARIABLES=dep_pc  (A) BY milieu  /NTILES (10) /PRINT=NO
  /TIES=MEAN .
RANK
  VARIABLES=dep_pc  (A) /NTILES (5) /PRINT=NO
  /TIES=MEAN .
RANK
  VARIABLES=dep_pc  (A) /NTILES (10) /PRINT=NO
  /TIES=MEAN .
SAVE OUTFILE='C:\_Maroc\Data\Spss\Annuel\Dep_cat.sav'
   /COMPRESSED.

COMPUTE  Quin_pur = ndep_pc.
COMPUTE  Deci_pur = nti001.
COMPUTE  Quin_pn = nti002.
COMPUTE  Deci_pn = nti003.
EXECUTE.

VARIABLE LABELS
   	 Quin_pur   'Quintile de pop. U/R'
	/Deci_pur   'Dcile de population U/R'
      /Quin_pn    'Quintile de pop. national'
      /Deci_pn    'Dcile de pop. national'.
SAVE OUTFILE='C:\_Maroc\Data\Spss\Annuel\Dep_cat.sav'
   /DROP ndep_pc nti001 nti002 nti003
   /COMPRESSED.
  
* Production de tableaux de contrle *.
* ---------------------------------- *.

* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000002 "Total" $t000001 "Total"
  /TABLE=quin_pur + $t000002  BY milieu > (STATISTICS) + $t000001
  /STATISTICS
  count( quin_pur( F5.0 ))
  cpct( quin_pur( PCT5.1 ) 'Col %':milieu ) /TITLE  'Population quintiles - U/R'
  '' /CAPTION  'Computed separately for urban and rural population.' 'Based on'+
 ' per_capita expenditure.'.

* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000003 "Total" $t000001 "Total"
  /TABLE=deci_pur + $t000003  BY milieu > (STATISTICS) + $t000001
  /STATISTICS
  count( deci_pur( F5.0 ))
  cpct( deci_pur( PCT5.1 ) 'Col %':milieu ) /TITLE  'Population deciles - U/R' ''
 /CAPTION  'Computed separately for urban and rural population.' 'Based on'+
 ' per_capita expenditure.'.

* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000001 "Total"
  /TABLE=quin_pn + $t000004  BY milieu > (STATISTICS) + $t000001
  /STATISTICS
  count( quin_pn( F5.0 ))
  cpct( quin_pn( PCT5.1 ) 'Col %':milieu ) /TITLE  'Population quintiles - National' ''
 /CAPTION  'Computed at national level' 'Based on per_capita expenditure.'.

* General Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000005 "Total" $t000001 "Total"
  /TABLE=deci_pn + $t000005  BY milieu > (STATISTICS) + $t000001
  /STATISTICS
  count( deci_pn( F5.0 ))
  cpct( deci_pn( PCT5.1 ) 'Col %':milieu ) /TITLE  'Population deciles -'+
 ' National' '' /CAPTION  'Computed at national level' 'Based on per_capita'+
 ' expenditure.'.
